@@ -894,11 +894,16 @@ ui_set_mode(ModeType mode)
     if (X.mode != mode) {
         X.mode = mode;
 
-        ui_set_base(DEC);
-        ui_set_numeric_mode(FIX);
-        do_button(FN_SET_ACCURACY, DEFAULT_ACCURACY);
-        ui_set_show_thousands_separator(FALSE);
-        ui_set_show_trailing_zeroes(FALSE);
+        // FIXME: These should affect display but not the actual UI settings
+        if (mode != PROGRAMMING)
+            ui_set_base(DEC);
+        if (mode != SCIENTIFIC) {
+            ui_set_numeric_mode(FIX);
+            do_button(FN_SET_ACCURACY, DEFAULT_ACCURACY);
+        }
+        if (mode == BASIC)
+            ui_set_show_trailing_zeroes(FALSE);
+
         ui_make_registers();
     }
     
@@ -1201,8 +1206,8 @@ about_cb(GtkWidget *widget)
     /* Translators: The translator credits. Please translate this with your name(s). */
     const gchar *translator_credits = _("translator-credits");
 
-    char *license[] = {
-        /* Translators: The license this software is under (GPL2+) */
+    /* Translators: The license this software is under (GPL2+) */
+    char *license =
         _("Gcalctool is free software; you can redistribute it and/or modify\n"
           "it under the terms of the GNU General Public License as published by\n"
           "the Free Software Foundation; either version 2 of the License, or\n"
@@ -1215,8 +1220,7 @@ about_cb(GtkWidget *widget)
           "\n"
           "You should have received a copy of the GNU General Public License\n"
           "along with Gcalctool; if not, write to the Free Software Foundation, Inc.,\n"
-          "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA\n")
-    };
+          "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA\n");
 
     gtk_show_about_dialog(GTK_WINDOW(X.kframe),
                           /* Translators: Program name in the about dialog */
@@ -2830,7 +2834,7 @@ ui_load(void)
     ui_set_show_trailing_zeroes(v->display.show_zeroes);
     
     ui_set_mode(X.mode);
-    ui_set_numeric_mode(FIX);
+    ui_set_numeric_mode(v->display.format);
     ui_set_base(v->base);
     ui_set_accuracy(v->accuracy);
     ui_set_undo_enabled(FALSE, FALSE);
